@@ -36,7 +36,7 @@ define(['jquery', 'base/js/namespace', 'base/js/utils'], function($, Jupyter, ut
                 var $entry_link = $('<a>')
                     .attr('role', 'menuitem')
                     .attr('tabindex', '-1')
-                    .attr('href', base_url + server_process.name + '/')
+                    .attr('href', base_url + server_process.launcher_entry.path_info)
                     .attr('target', '_blank')
                     .text(server_process.launcher_entry.title);
 
